const express = require('express');
const term = require('terminal-kit').terminal;
const bodyParser = require('body-parser');
const path = require('path');
const axios = require('axios').default;
const figlet = require('figlet');

const app = express();
const config = require('../config.json');
const { version } = require('../package.json');

for ([key, value] of Object.entries(config)) {
	if (key === 'siteInfo' && Object.values(value).includes('')) {
		term(
			`^r[Error]:^ You must input values for items within the ^c"siteInfo"^ part of the config!\n`
		);
		process.exit();
	}
	if (key === 'metaData' && Object.values(value).includes('')) {
		term(
			`^r[Error]:^ You must input values for items within the ^c"metaData"^ part of the config!\n`
		);
		process.exit();
	}
	if (key === 'colors' && Object.values(value).includes('')) {
		term(
			`^r[Error]:^ You must input values for items within the ^c"colors"^ part of the config!\n`
		);
		process.exit();
	}
	if (key === 'cardData') {
		if (
			value.title === '' ||
			value.description === '' ||
			value.findText === ''
		) {
			term(
				`^r[Error]:^ You must input values for the title, description, and/or findText within the ^c"cardData"^ part of the config!\n`
			);
			process.exit();
		}
		if (value.button.active) {
			if (value.button.link === '' || value.button.text === '') {
				term(
					`^r[Error]:^ You must input values for button link and/or text since the button is active within the ^c"cardData"^ part of the config!\n`
				);
				process.exit();
			}
		}
	}
}

app.locals.config = config;
app.locals.domain = config.siteInfo.domain;
app.locals.colors = config.colors;

app.use(bodyParser.urlencoded({ extended: true }));
app.set('view engine', 'ejs');
app.set('views', path.join(__dirname, '/views'));
app.use(express.static('public'));

app.get('*', (req, res) => {
	res.status(404).render('index');
});

app.listen(config.siteInfo.port, async () => {
	let versionCheck = await axios({
		method: 'GET',
		url: `https://shadowdevs.com/api/version/check?version=${encodeURIComponent(
			version
		)}&product=33`,
		headers: {
			Accept: 'application/json, text/plain, */*',
			'User-Agent': '*',
		},
	}).catch(function (err) {});
	await term.cyan(
		figlet.textSync('Personal Card', {
			width: 100,
			horizontalLayout: 'fitted',
			whitespaceBreak: true,
		})
	);
	await term(
		`\nCreated By: ^KShadow Development^ (^chttps://shadowdevs.com^w)
^g[Success]:^ Personal Card is now loaded & online on port ^g${
			config.siteInfo.port
		}^w
━━━━━━━━━━━ Version ━━━━━━━━━━━
${
	versionCheck?.data.same
		? '^GYou are up to date, good job!'
		: '^yUpdate Required! Please visit: https://shadowdevs.com/releases/33'
}
^b[Your Version]:^ ${versionCheck?.data.same ? version : '^r' + version + '^w'}
^b[Latest Version]:^ ${versionCheck?.data.release.version}${
			!versionCheck?.data.same
				? '\n^b[Changelog]:^ ' + versionCheck?.data.release.changelog
				: ''
		}
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━\n`
	);
});
